<?php
session_start();
include 'config.php';

if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header('Location: login.php');
    exit();
}

// Get statistics
$sql_invoices = "SELECT COUNT(*) as invoice_count, SUM(total) as total_revenue FROM invoices";
$sql_customers = "SELECT COUNT(*) as customer_count FROM customers";
$sql_products = "SELECT COUNT(*) as product_count FROM products";

$result_invoices = $conn->query($sql_invoices);
$result_customers = $conn->query($sql_customers);
$result_products = $conn->query($sql_products);

$stats = [
    'invoices' => $result_invoices->fetch_assoc(),
    'customers' => $result_customers->fetch_assoc(),
    'products' => $result_products->fetch_assoc()
];
?>

<!DOCTYPE html>
<html dir="rtl">
<head>
    <title>لوحة التحكم</title>
    <style>
        .dashboard {
            max-width: 1200px;
            margin: 20px auto;
            padding: 20px;
        }
        .stats {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }
        .stat-card {
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        .recent-items {
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        table {
            width: 100%;
            border-collapse: collapse;
        }
        th, td {
            padding: 10px;
            border: 1px solid #ddd;
        }
    </style>
</head>
<body>
    <div class="dashboard">
        <h1>لوحة التحكم</h1>
        
        <div class="stats">
            <div class="stat-card">
                <h3>إجمالي الفواتير</h3>
                <p><?php echo $stats['invoices']['invoice_count']; ?></p>
                <p>الإيرادات: <?php echo number_format($stats['invoices']['total_revenue'], 2); ?> ريال</p>
            </div>
            
            <div class="stat-card">
                <h3>عدد العملاء</h3>
                <p><?php echo $stats['customers']['customer_count']; ?></p>
            </div>
            
            <div class="stat-card">
                <h3>عدد المنتجات</h3>
                <p><?php echo $stats['products']['product_count']; ?></p>
            </div>
        </div>
        
        <div class="recent-items">
            <h2>آخر الفواتير</h2>
            <table>
                <thead>
                    <tr>
                        <th>رقم الفاتورة</th>
                        <th>العميل</th>
                        <th>التاريخ</th>
                        <th>المبلغ</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    $sql = "SELECT i.*, c.name as customer_name 
                           FROM invoices i 
                           JOIN customers c ON i.customer_id = c.id 
                           ORDER BY i.invoice_date DESC LIMIT 10";
                    $result = $conn->query($sql);
                    while ($row = $result->fetch_assoc()) {
                        echo "<tr>";
                        echo "<td>{$row['invoice_number']}</td>";
                        echo "<td>{$row['customer_name']}</td>";
                        echo "<td>{$row['invoice_date']}</td>";
                        echo "<td>" . number_format($row['total'], 2) . "</td>";
                        echo "</tr>";
                    }
                    ?>
                </tbody>
            </table>
        </div>
    </div>
</body>
</html>