<?php
session_start();
include 'config.php';

if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}
?>

<!DOCTYPE html>
<html dir="rtl">
<head>
    <title>إنشاء فاتورة جديدة</title>
    <style>
        .invoice-form {
            max-width: 800px;
            margin: 20px auto;
            padding: 20px;
            background: white;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        .form-group {
            margin-bottom: 15px;
        }
        .products-table {
            width: 100%;
            border-collapse: collapse;
            margin: 15px 0;
        }
        .products-table th, .products-table td {
            border: 1px solid #ddd;
            padding: 8px;
        }
        .company-logo {
            text-align: center;
            margin-bottom: 20px;
        }
    </style>
    <script>
        function calculateTotal() {
            let subtotal = 0;
            const rows = document.querySelectorAll('.product-row');
            
            rows.forEach(row => {
                const quantity = parseFloat(row.querySelector('.quantity').value) || 0;
                const price = parseFloat(row.querySelector('.price').value) || 0;
                subtotal += quantity * price;
            });
            
            const tax = subtotal * 0.15; // 15% VAT
            const total = subtotal + tax;
            
            document.getElementById('subtotal').value = subtotal.toFixed(2);
            document.getElementById('tax').value = tax.toFixed(2);
            document.getElementById('total').value = total.toFixed(2);
        }
        
        function addProductRow() {
            const table = document.querySelector('.products-table tbody');
            const newRow = document.createElement('tr');
            newRow.className = 'product-row';
            newRow.innerHTML = `
                <td><input type="text" class="product-name" required></td>
                <td><input type="number" class="quantity" onchange="calculateTotal()" required></td>
                <td><input type="number" step="0.01" class="price" onchange="calculateTotal()" required></td>
                <td><button type="button" onclick="this.parentElement.parentElement.remove(); calculateTotal()">حذف</button></td>
            `;
            table.appendChild(newRow);
        }
    </script>
</head>
<body>
    <div class="invoice-form">
        <div class="company-logo">
            <img src="logo.png" alt="شعار الشركة" style="max-width: 200px;">
        </div>
        
        <form method="POST" action="save_invoice.php">
            <div class="form-group">
                <h3>بيانات العميل</h3>
                <input type="text" name="customer_name" placeholder="اسم العميل" required>
                <input type="text" name="customer_address" placeholder="العنوان">
                <input type="tel" name="customer_phone" placeholder="رقم الهاتف">
            </div>
            
            <div class="form-group">
                <h3>تفاصيل المنتجات</h3>
                <table class="products-table">
                    <thead>
                        <tr>
                            <th>المنتج</th>
                            <th>الكمية</th>
                            <th>السعر</th>
                            <th>إجراءات</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr class="product-row">
                            <td><input type="text" class="product-name" required></td>
                            <td><input type="number" class="quantity" onchange="calculateTotal()" required></td>
                            <td><input type="number" step="0.01" class="price" onchange="calculateTotal()" required></td>
                            <td><button type="button" onclick="this.parentElement.parentElement.remove(); calculateTotal()">حذف</button></td>
                        </tr>
                    </tbody>
                </table>
                <button type="button" onclick="addProductRow()">إضافة منتج</button>
            </div>
            
            <div class="form-group">
                <h3>الإجمالي</h3>
                <input type="number" id="subtotal" name="subtotal" readonly>
                <input type="number" id="tax" name="tax" readonly>
                <input type="number" id="total" name="total" readonly>
            </div>
            
            <button type="submit">حفظ الفاتورة</button>
            <button type="button" onclick="window.print()">طباعة</button>
        </form>
    </div>
</body>
</html>