<?php
session_start();
require_once 'config.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // معالجة بيانات الفاتورة
    $client_name = $_POST['client_name'];
    $client_address = $_POST['client_address'];
    $client_phone = $_POST['client_phone'];
    
    // إدخال البيانات في قاعدة البيانات
    $sql = "INSERT INTO clients (name, address, phone) VALUES (?, ?, ?)";
    $stmt = $conn->prepare($sql);
    $stmt->execute([$client_name, $client_address, $client_phone]);
    
    // إنشاء الفاتورة
    // ... (المزيد من الكود لمعالجة تفاصيل الفاتورة)
}
?>
<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إنشاء فاتورة - شركة الزي الموحد</title>
    <style>
        /* نفس الأنماط السابقة مع إضافات */
        .invoice-form {
            background-color: white;
            padding: 30px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            margin: 20px 0;
        }

        .form-group {
            margin-bottom: 20px;
        }

        label {
            display: block;
            margin-bottom: 8px;
            font-weight: bold;
        }

        input, select, textarea {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .btn {
            background-color: var(--primary-color);
            color: white;
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .btn:hover {
            background-color: var(--secondary-color);
        }

        .items-table {
            width: 100%;
            border-collapse: collapse;
            margin: 20px 0;
        }

        .items-table th, .items-table td {
            border: 1px solid #ddd;
            padding: 8px;
            text-align: right;
        }
    </style>
</head>
<body>
    <header>
        <!-- نفس الهيدر السابق -->
    </header>

    <main class="container">
        <h2>إنشاء فاتورة جديدة</h2>
        
        <form class="invoice-form" method="POST">
            <div class="form-group">
                <h3>بيانات العميل</h3>
                <label for="client_name">اسم العميل</label>
                <input type="text" id="client_name" name="client_name" required>
                
                <label for="client_address">العنوان</label>
                <textarea id="client_address" name="client_address" required></textarea>
                
                <label for="client_phone">رقم الهاتف</label>
                <input type="tel" id="client_phone" name="client_phone" required>
            </div>

            <div class="form-group">
                <h3>تفاصيل الطلب</h3>
                <table class="items-table">
                    <thead>
                        <tr>
                            <th>المنتج</th>
                            <th>الكمية</th>
                            <th>السعر</th>
                            <th>الإجمالي</th>
                            <th></th>
                        </tr>
                    </thead>
                    <tbody id="items-tbody">
                        <tr>
                            <td>
                                <select name="products[]" required>
                                    <option value="">اختر المنتج</option>
                                    <!-- يتم ملء الخيارات من قاعدة البيانات -->
                                </select>
                            </td>
                            <td><input type="number" name="quantities[]" min="1" required></td>
                            <td><input type="number" name="prices[]" step="0.01" required></td>
                            <td class="total">0</td>
                            <td><button type="button" class="btn remove-item">حذف</button></td>
                        </tr>
                    </tbody>
                </table>
                <button type="button" class="btn" id="add-item">إضافة منتج</button>
            </div>

            <div class="form-group">
                <label for="tax">ضريبة القيمة المضافة (%)</label>
                <input type="number" id="tax" name="tax" value="15" min="0" max="100">
                
                <div class="totals">
                    <p>المجموع قبل الضريبة: <span id="subtotal">0</span> ريال</p>
                    <p>قيمة الضريبة: <span id="tax-amount">0</span> ريال</p>
                    <p>الإجمالي النهائي: <span id="final-total">0</span> ريال</p>
                </div>
            </div>

            <button type="submit" class="btn">إنشاء الفاتورة</button>
        </form>
    </main>

    <script>
        // حساب المجاميع
        function calculateTotals() {
            let subtotal = 0;
            document.querySelectorAll('tr').forEach(row => {
                const quantity = parseFloat(row.querySelector('input[name="quantities[]"]')?.value || 0);
                const price = parseFloat(row.querySelector('input[name="prices[]"]')?.value || 0);
                const total = quantity * price;
                row.querySelector('.total').textContent = total.toFixed(2);
                subtotal += total;
            });

            const taxRate = parseFloat(document.getElementById('tax').value) / 100;
            const taxAmount = subtotal * taxRate;
            const finalTotal = subtotal + taxAmount;

            document.getElementById('subtotal').textContent = subtotal.toFixed(2);
            document.getElementById('tax-amount').textContent = taxAmount.toFixed(2);
            document.getElementById('final-total').textContent = finalTotal.toFixed(2);
        }

        // إضافة منتج جديد
        document.getElementById('add-item').addEventListener('click', function() {
            const tbody = document.getElementById('items-tbody');
            const newRow = tbody.rows[0].cloneNode(true);
            tbody.appendChild(newRow);
            
            newRow.querySelectorAll('input').forEach(input => input.value = '');
            newRow.querySelector('.total').textContent = '0';
            
            // إعادة ربط الأحداث
            attachEvents();
        });

        function attachEvents() {
            // حذف منتج
            document.querySelectorAll('.remove-item').forEach(btn => {
                btn.onclick = function() {
                    if (document.querySelectorAll('tr').length > 1) {
                        this.closest('tr').remove();
                        calculateTotals();
                    }
                };
            });

            // حساب المجاميع عند تغيير القيم
            document.querySelectorAll('input').forEach(input => {
                input.addEventListener('input', calculateTotals);
            });
        }

        attachEvents();
    </script>
</body>
</html>